/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999-2004 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CreateJonasServerAction.java 10874 2007-07-06 17:45:37Z eyindanga $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.domain;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;

import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.oname.J2eeObjectName;
import org.objectweb.jonas.management.j2eemanagement.J2EEDomain;
import org.objectweb.jonas.management.monitoring.DomainMonitor;
import org.objectweb.jonas.management.monitoring.proxy.clusterd.ClusterDaemonProxy;
import org.objectweb.jonas.management.monitoring.proxy.server.ServerProxy;
import org.objectweb.jonas.webapp.jonasadmin.JonasManagementRepr;
import org.objectweb.jonas.webapp.jonasadmin.JonasBaseAction;
import org.objectweb.jonas.webapp.jonasadmin.common.BeanComparator;

/**
 * This action is called when adding a server to the domain (Add server button).
 * @author Adriana Danes
 */
public class CreateJonasServerAction extends JonasBaseAction {

//	--------------------------------------------------------- Public Methods
    @SuppressWarnings("unchecked")
    public ActionForward executeAction(ActionMapping p_Mapping, ActionForm p_Form
            , HttpServletRequest p_Request, HttpServletResponse p_Response)
    throws IOException, ServletException {

        // Form used
        NewServerForm oForm = new NewServerForm();
        m_Session.setAttribute("newServerForm", oForm);
        String clusterName = (String) m_Session.getAttribute("currentCluster");
        String clusterDaemonName=p_Request.getParameter("CdName");
        String domainName = m_WhereAreYou.getCurrentDomainName();
//		first set the attribute to know if the alreaday have the ClusterDameon name or not
        p_Request.setAttribute("CdName", clusterDaemonName);
        if(clusterDaemonName!=null)
        {
            m_WhereAreYou.setCurrentClusterDaemonName(clusterDaemonName);
//			getting requested cluster daemon Administred Jonas servers...
            DomainMonitor dm = J2EEDomain.getInstance().getDomainMonitor();
//			Get servers running in this domain
            ArrayList al = new ArrayList();
            //are all the servers already started ?
            //getting the cluster daemon proxy from domain monitor
            ClusterDaemonProxy cdProx=dm.findClusterDaemonProxy(clusterDaemonName);
            ObjectName on = null;
            if (cdProx!=null) {
                for (Iterator it = dm.getServerList().iterator(); it.hasNext();) {
                    ServerProxy proxy = (ServerProxy) it.next();
                    try {
                        on = ObjectName.getInstance(proxy.getName());
                    } catch (MalformedObjectNameException e) {
                        e.printStackTrace();
                        return null;
                    } catch (NullPointerException e) {
                        // TODO Auto-generated catch block
                        e.printStackTrace();
                        return null;
                    }
                    String cdName=proxy.getClusterDaemonName();
                    if (cdName == null) {
                        al.add(new ServerItem(on,proxy.getState(),null));

                    }

                }
                Collections.sort(al, new BeanComparator(new String[] {"name"}));
                //this list will be used in the forward destination.
                p_Request.setAttribute("freeServersList", al);
            }
            return (p_Mapping.findForward("AddServerToClusterDaemon"));

        }
        // Current JOnAS server
        String jonasServerName =  m_WhereAreYou.getCurrentJonasServerName();
        // Forward to the jsp.
        if (domainName.equals(clusterName)) {
            return (p_Mapping.findForward("AddServerToDomain"));
        } else {
            oForm.setCluster(true);
            ObjectName domainOn = J2eeObjectName.J2EEDomain(domainName);
            Object[] asParam = {clusterName};
            String[] asSignature = {"java.lang.String"};
            String[] serverNames = (String[]) JonasManagementRepr.invoke(domainOn
                    , "getServersNotInCluster", asParam, asSignature
                    , jonasServerName);
            oForm.setServerNames(serverNames);
            return (p_Mapping.findForward("AddServerToCluster"));
        }
    }
}