/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2003-2005 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ServerItem.java 10873 2007-07-06 17:41:47Z eyindanga $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.domain;

import javax.management.ObjectName;

import org.objectweb.jonas.webapp.jonasadmin.common.ObjectNameItem;

public class ServerItem extends ObjectNameItem {
    /**
     * server state
     */
    private String state = null;
    /**
     * url used to connect on JMX remote server
     */
    private String url = null;

    private String clusterDaemonName = null;
    //true if this server is in clusterd.xml
    private boolean isInCdConfig;
    //the following informations are needed for cluster daemon configuration file (clusterd.xml)
    //the server description
    String description = "Empty";
    String javaHome = "Empty";
    String jonasRoot = "Empty";
    String jonasBase = "Empty";

    public ServerItem(ObjectName pObjectName, String pState, String pClusterDaemonName) {
        super(pObjectName);
        this.state = pState;
        this.clusterDaemonName = pClusterDaemonName;
    }
    /**
     *
     * @param pObjectName
     * @param pState
     * @param pClusterDaemonName
     * @param isInCdConfig
     */
    public ServerItem(ObjectName pObjectName, String pState, String pClusterDaemonName,boolean isInCdConfig) {
        super(pObjectName);
        this.state = pState;
        this.clusterDaemonName = pClusterDaemonName;
        this.isInCdConfig=isInCdConfig;
    }
    /**
     * @return Returns the url.
     */
    public String getUrl() {
        return url;
    }
    /**
     * @param url The url to set.
     */
    public void setUrl(String url) {
        this.url = url;
    }
    /**
     * @return Returns the state.
     */
    public String getState() {
        return state;
    }

    /**
     * @param state The state to set.
     */
    public void setState(String state) {
        this.state = state;
    }

    /**
     * @return the cluster daemon's name or null if no cluster daemon
     */
    public String getClusterDaemonName() {
        return clusterDaemonName;
    }
    /**
     *
     * @return true if the server is in the clusterd.xml
     */
    public boolean getIsInCdConfig() {
        return isInCdConfig;
    }
    /**
     *
     * @param isInCdConfig
     */
    public void setIsInCdConfig(boolean isInCdConfig) {
        this.isInCdConfig = isInCdConfig;
    }
    public void setClusterDaemonName(String clusterDaemonName) {
        this.clusterDaemonName = clusterDaemonName;
    }
    /**
     * @return the description
     */
    public String getDescription() {
        return description;
    }
    /**
     * @param description the description to set
     */
    public void setDescription(String description) {
        this.description = description;
    }
    /**
     * @return the javaHome
     */
    public String getJavaHome() {
        return javaHome;
    }
    /**
     * @param javaHome the javaHome to set
     */
    public void setJavaHome(String javaHome) {
        this.javaHome = javaHome;
    }
    /**
     * @return the jonasBase
     */
    public String getJonasBase() {
        return jonasBase;
    }
    /**
     * @param jonasBase the jonasBase to set
     */
    public void setJonasBase(String jonasBase) {
        this.jonasBase = jonasBase;
    }
    /**
     * @return the jonasRoot
     */
    public String getJonasRoot() {
        return jonasRoot;
    }
    /**
     * @param jonasRoot the jonasRoot to set
     */
    public void setJonasRoot(String jonasRoot) {
        this.jonasRoot = jonasRoot;
    }
    /**
     * @param isInCdConfig the isInCdConfig to set
     */
    public void setInCdConfig(boolean isInCdConfig) {
        this.isInCdConfig = isInCdConfig;
    }
}